library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

package e7cores_pkg is

  component e7udpip100M_spartan6
    generic (
      TARGETFPGA : string := "SPARTAN6"
      );
    port(
      -- GMII PHY : 2.5V
      EPHY_RST_N    : out   std_logic ;  -- このchipにおけるシステムリセットを出す
      EPHY_MAC_CLK  : in    std_logic ;  -- PHYからの25MHzCLK入力
      -- MAC I/F
      EPHY_COL      : in    std_logic ;  -- CollisionDetect/MAC_FREQ兼用ピン。外部で2kPUされている。＝＞MAC_CLK出力を125MHzにしている様。
      EPHY_CRS      : in    std_logic ;  -- CarrierSence/RGMII_SEL0兼用ピン。外部で2kPDされている。
      EPHY_TXCLK    : in    std_logic ;  -- TXCLK/RGMII_SEL1兼用ピン。外部で2kPDされている。＝＞CRSと合わせてGMIIモードにしている。
      -- TX out
      EPHY_TD       : out   std_logic_vector( 3 downto 0 ) ;  -- 送信データ
      EPHY_TXEN     : out   std_logic ;
      EPHY_TXER     : out   std_logic ;
      -- RX in
      EPHY_RD       : in    std_logic_vector( 3 downto 0 ) ;  -- 受信データ
      EPHY_RXCLK    : in    std_logic ;  -- 10M=>2.5MHz, 100M=>25MHz, 1G=>125MHz のクロックが来る
      EPHY_RXDV     : in    std_logic ;
      EPHY_RXER     : in    std_logic ;
      -- Management I/F
      EPHY_MDC      : out   std_logic ;  -- クロック出力。max.2.5MHz。
      EPHY_MDIO     : inout std_logic ;  -- コントロールデータ。
      EPHY_INT_N    : in    std_logic ;  -- インタラプト。

      -- Asynchronous Reset
      Reset_n        : in  std_logic;

      -- UPL interface
      pUPLGlobalClk : in  std_logic;
      -- UDP tx input
      pUdp0Send_Data       : in  std_logic_vector( 31 downto 0 );
      pUdp0Send_Request    : in  std_logic;
      pUdp0Send_Ack        : out std_logic;
      pUdp0Send_Enable     : in  std_logic;

      pUdp1Send_Data       : in  std_logic_vector( 31 downto 0 );
      pUdp1Send_Request    : in  std_logic;
      pUdp1Send_Ack        : out std_logic;
      pUdp1Send_Enable     : in  std_logic;

      -- UDP rx output
      pUdp0Receive_Data       : out std_logic_vector( 31 downto 0 );
      pUdp0Receive_Request    : out std_logic;
      pUdp0Receive_Ack        : in  std_logic;
      pUdp0Receive_Enable     : out std_logic;

      pUdp1Receive_Data       : out std_logic_vector( 31 downto 0 );
      pUdp1Receive_Request    : out std_logic;
      pUdp1Receive_Ack        : in  std_logic;
      pUdp1Receive_Enable     : out std_logic;

      -- Setup
      pMyIpAddr       : in std_logic_vector( 31 downto 0 );
      pMyMacAddr      : in std_logic_vector( 47 downto 0 );
      pMyNetmask      : in std_logic_vector( 31 downto 0 );
      pDefaultGateway : in std_logic_vector( 31 downto 0 );
      pTargetIPAddr   : in std_logic_vector( 31 downto 0 );
      pMyUdpPort0     : in std_logic_vector( 15 downto 0 );
      pMyUdpPort1     : in std_logic_vector( 15 downto 0 );

      -- Status
      pStatus_RxByteCount             : out std_logic_vector( 31 downto 0 );
      pStatus_RxPacketCount           : out std_logic_vector( 31 downto 0 );
      pStatus_RxErrorPacketCount      : out std_logic_vector( 15 downto 0 );
      pStatus_RxDropPacketCount       : out std_logic_vector( 15 downto 0 );
      pStatus_RxARPRequestPacketCount : out std_logic_vector( 15 downto 0 );
      pStatus_RxARPReplyPacketCount   : out std_logic_vector( 15 downto 0 );
      pStatus_RxICMPPacketCount       : out std_logic_vector( 15 downto 0 );
      pStatus_RxUDP0PacketCount       : out std_logic_vector( 15 downto 0 );
      pStatus_RxUDP1PacketCount       : out std_logic_vector( 15 downto 0 );
      pStatus_RxIPErrorPacketCount    : out std_logic_vector( 15 downto 0 );
      pStatus_RxUDPErrorPacketCount   : out std_logic_vector( 15 downto 0 );

      pStatus_TxByteCount             : out std_logic_vector( 31 downto 0 );
      pStatus_TxPacketCount           : out std_logic_vector( 31 downto 0 );
      pStatus_TxARPRequestPacketCount : out std_logic_vector( 15 downto 0 );
      pStatus_TxARPReplyPacketCount   : out std_logic_vector( 15 downto 0 );
      pStatus_TxICMPReplyPacketCount  : out std_logic_vector( 15 downto 0 );
      pStatus_TxUDP0PacketCount       : out std_logic_vector( 15 downto 0 );
      pStatus_TxUDP1PacketCount       : out std_logic_vector( 15 downto 0 );
      pStatus_TxMulticastPacketCount  : out std_logic_vector( 15 downto 0 );

      pdebug : out std_logic_vector(63 downto 0)
      );
  end component;

end e7cores_pkg;
